==> mozc_1.11.1522.102.orig.tar.bz2: mozc-1.11.1522.102/base/update_util.h <==
// Copyright 2010-2013, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_BASE_UPDATE_UTIL_H_
#define MOZC_BASE_UPDATE_UTIL_H_

#include <string>

namespace mozc {

class UpdateUtil {
 public:
  // Writes a registry value for usage tracking by Omaha.
  // Returns true if the value is successfully written.
  static bool WriteActiveUsageInfo();

  // Returns the version which is available after reboot.
  // If no update is available returns the current version.
  static string GetAvailableVersion();

  // Returns the version of Mozc which is currently running.
  static string GetCurrentVersion();

  // Returns true if new version is available after reboot.
  static bool IsNewVersionAvailable();

  // Returns true if lhs is less than rhs in the lexical order.
  // CompareVersion("1.2.3.4", "1.2.3.4") => false
  // CompareVersion("1.2.3.4", "5.2.3.4") => true
  // CompareVersion("1.25.3.4", "1.2.3.4") => false
  static bool CompareVersion(const string &lhs, const string &rhs);

 private:
  UpdateUtil() {}
  virtual ~UpdateUtil() {}
};

}  // namespace mozc

#endif  // MOZC_BASE_UPDATE_UTIL_H_

==> mozc_1.12.1599.102.orig.tar.bz2: mozc-1.12.1599.102/base/update_util.h <==
// Copyright 2010-2013, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_BASE_UPDATE_UTIL_H_
#define MOZC_BASE_UPDATE_UTIL_H_

#include "base/port.h"

namespace mozc {

class UpdateUtil {
 public:
  // Writes a registry value for usage tracking by Omaha.
  // Returns true if the value is successfully written.
  static bool WriteActiveUsageInfo();

 private:
  DISALLOW_IMPLICIT_CONSTRUCTORS(UpdateUtil);
};

}  // namespace mozc

#endif  // MOZC_BASE_UPDATE_UTIL_H_
